@@ -13,7 +13,7 @@ extern "C" {
 
 
 /** Defines the Baresip version string */
-#define BARESIP_VERSION "3.15.0"
+#define BARESIP_VERSION "3.17.0"
 
 
 #ifndef NET_MAX_NS
@@ -270,6 +270,7 @@ const struct list *call_get_custom_hdrs(const struct call *call);
 void call_set_media_direction(struct call *call, enum sdp_dir a,
 			     enum sdp_dir v);
 void call_set_mdir(struct call *call, enum sdp_dir a, enum sdp_dir v);
+void call_get_mdir(struct call *call, enum sdp_dir *ap, enum sdp_dir *vp);
 void call_set_media_estdir(struct call *call, enum sdp_dir a, enum sdp_dir v);
 void call_start_answtmr(struct call *call, uint32_t ms);
 bool          call_supported(struct call *call, uint16_t tags);
@@ -310,7 +311,7 @@ typedef int (confline_h)(const struct pl *addr, void *arg);
 int  conf_configure(void);
 int  conf_configure_buf(const uint8_t *buf, size_t sz);
 int  conf_modules(void);
-void conf_path_set(const char *path);
+int  conf_path_set(const char *path);
 int  conf_path_get(char *path, size_t sz);
 int  conf_parse(const char *filename, confline_h *ch, void *arg);
 int  conf_get_range(const struct conf *conf, const char *name,
@@ -372,6 +373,7 @@ struct config_call {
 	uint32_t local_timeout; /**< Incoming call timeout [sec] 0=off    */
 	uint32_t max_calls;     /**< Maximum number of calls, 0=unlimited */
 	bool hold_other_calls;  /**< Hold other calls */
+	bool accept;            /**< Accept call by baresip core          */
 };
 
 /** Audio */
@@ -581,6 +583,8 @@ typedef void (ausrc_error_h)(int err, const char *str, void *arg);
 typedef int  (ausrc_alloc_h)(struct ausrc_st **stp, const struct ausrc *ausrc,
 			     struct ausrc_prm *prm, const char *device,
 			     ausrc_read_h *rh, ausrc_error_h *errh, void *arg);
+typedef int  (ausrc_info_h)(const struct ausrc *ausrc,
+			    struct ausrc_prm *prm, const char *device);
 
 /** Defines an Audio Source */
 struct ausrc {
@@ -588,6 +592,7 @@ struct ausrc {
 	const char      *name;
 	struct list      dev_list;
 	ausrc_alloc_h   *alloch;
+	ausrc_info_h    *infoh;
 };
 
 int ausrc_register(struct ausrc **asp, struct list *ausrcl, const char *name,
@@ -597,6 +602,8 @@ int ausrc_alloc(struct ausrc_st **stp, struct list *ausrcl,
 		const char *name,
 		struct ausrc_prm *prm, const char *device,
 		ausrc_read_h *rh, ausrc_error_h *errh, void *arg);
+int ausrc_info(struct list *ausrcl,
+	       const char *name, struct ausrc_prm *prm, const char *device);
 
 
 /*
@@ -909,6 +916,7 @@ int  ua_connect_dir(struct ua *ua, struct call **callp,
 		    enum vidmode vmode, enum sdp_dir adir, enum sdp_dir vdir);
 void ua_hangup(struct ua *ua, struct call *call,
 	       uint16_t scode, const char *reason);
+int  ua_accept(struct ua *ua, const struct sip_msg *msg);
 int  ua_answer(struct ua *ua, struct call *call, enum vidmode vmode);
 int  ua_hold_answer(struct ua *ua, struct call *call, enum vidmode vmode);
 int  ua_options_send(struct ua *ua, const char *uri,
@@ -968,8 +976,6 @@ int  uag_hold_others(struct call *call);
 void uag_set_nodial(bool nodial);
 bool uag_nodial(void);
 void uag_set_exit_handler(ua_exit_h *exith, void *arg);
-void uag_set_dnd(bool dnd);
-bool uag_dnd(void);
 void uag_enable_sip_trace(bool enable);
 int  uag_reset_transp(bool reg, bool reinvite);
 void uag_set_sub_handler(sip_msg_h *subh);
@@ -1543,6 +1549,7 @@ struct jbuf_stat {
 
 int  jbuf_alloc(struct jbuf **jbp, uint32_t min, uint32_t max);
 int  jbuf_set_type(struct jbuf *jb, enum jbuf_type jbtype);
+void jbuf_set_gnack(struct jbuf *jb, struct rtp_sock *rtp);
 int  jbuf_put(struct jbuf *jb, const struct rtp_header *hdr, void *mem);
 int  jbuf_get(struct jbuf *jb, struct rtp_header *hdr, void **mem);
 int  jbuf_drain(struct jbuf *jb, struct rtp_header *hdr, void **mem);
